pub struct AddPhaseCtx {
pub editions_controls: Pubkey,
pub payer: Pubkey,
pub creator: Pubkey,
pub system_program: Pubkey,
pub token_program: Pubkey,
pub libreplex_editions_program: Pubkey,
}Expand description
Generated client accounts for AddPhaseCtx.
Fields
editions_controls: Pubkeypayer: Pubkeycreator: Pubkeysystem_program: Pubkeytoken_program: Pubkeylibreplex_editions_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AddPhaseCtxwhere
Pubkey: BorshSerialize,
impl BorshSerialize for AddPhaseCtxwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for AddPhaseCtx
impl ToAccountMetas for AddPhaseCtx
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AddPhaseCtx
impl RefUnwindSafe for AddPhaseCtx
impl Send for AddPhaseCtx
impl Sync for AddPhaseCtx
impl Unpin for AddPhaseCtx
impl UnwindSafe for AddPhaseCtx